@@ -62,7 +62,7 @@ class get_selenium:
     }
 
     @staticmethod
-    def selenium_screenshot2pic(url, pic_name, size=(1920, 1080), pic_savepath=fr'pics', isMobile=False, mobileModel=None, showPosition=(0, 0), delay=3, log=False, chromedriverPath=r'./chromedriver.exe'):
+    def selenium_screenshot2pic(url, pic_name, size=(1920, 1080), pic_savepath=fr'pics', isMobile=False, mobileModel=None, showPosition=(0, 0), delay=3, log=False, chromedriverPath=r''):
         """
         selenium 浏览器截图
         :param url: 截图地址
@@ -136,11 +136,12 @@ class get_selenium:
         return get_selenium.selenium_object
 
     @staticmethod
-    def selenium_content(url, isMobile=False, log=False, chromedriverPath=r'./chromedriver.exe'):
+    def selenium_content(url, isMobile=False, mobileModel=None, log=False, chromedriverPath=r''):
         """
         selenium 获取内容
         :param url: 访问的url
         :param isMobile: 是否手机模式访问
+        :param mobileModel: 手机型号
         :param log: 显示日志
         :param chromedriverPath:  chromedriver路径
         :return:
@@ -155,13 +156,16 @@ class get_selenium:
         chrome_options.add_argument('--headless')  # 浏览器不提供可视化页面
 
         if isMobile:
-            # mobile_emulation = {
-            #     "deviceMetrics": {"width": 192, "height": 108, "pixelRatio": 3.0},  # 定义设备高宽，像素比
-            #     "userAgent": "Mozilla/5.0 (Linux; Android 4.2.1; en-us; Nexus 5 Build/JOP40D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19"  # 通过UA来模拟
-            # }
-            # chrome_options.add_experimental_option('mobileEmulation', mobile_emulation)
-
-            chrome_options.add_experimental_option("mobileEmulation", {"deviceName": "iPhone 6"})
+            if isinstance(mobileModel, int):
+                mobile_emulation = {"deviceName": get_selenium.mobileType[mobileModel - 1]}
+            elif isinstance(mobileModel, dict):
+                mobile_emulation = mobileModel
+            else:
+                mobile_emulation = {
+                    "deviceMetrics": {"width": 192, "height": 108, "pixelRatio": 3.0},  # 定义设备高宽，像素比
+                    "userAgent": "Mozilla/5.0 (Linux; Android 4.2.1; en-us; Nexus 5 Build/JOP40D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19"  # 通过UA来模拟
+                }
+            chrome_options.add_experimental_option('mobileEmulation', mobile_emulation)
 
         driver = webdriver.Chrome(options=chrome_options, service=Service(chromedriverPath))  # python新版本
         # driver = webdriver.Chrome(options=chrome_options, executable_path='../../self/20191014_selenium_getTitle/chromedriver_win32/chromedriver.exe')  # python旧版本
